@@ -1,3 +1,4 @@
+#' @importFrom utils read.csv
 read.xkcd <- function(file = NULL)
 {
   if(!is.null(file) && file.exists(file)) {
@@ -19,9 +20,10 @@ read.xkcd <- function(file = NULL)
 #'
 #' Update the XKCD database saved in the user directory
 #'
-#' This function update the local version of the XKCD database used by searchXKCD
+#' This function updates the local version of the XKCD database used
+#' by searchXKCD.
 #'
-#' @references http://xkcd.com/license.html
+#' @references \url{http://xkcd.com/license.html}
 #'
 #' @export
 #'
@@ -31,16 +33,16 @@ updateConfig <- function(){
 		stop("Use saveConfig() to save your xkcd database locally!")
 		} else load( paste(home, ".Rconfig/rxkcd.rda", sep="/") )
 	from <- dim(xkcd.df)[[1]]
-	current <- getXKCD("current", display=F)
+	current <- getXKCD("current", display=FALSE)
 	if ( current$num == xkcd.df$id[dim(xkcd.df)[[1]]] ) stop("Your local xkcd is already updated!")
 	tmp <- NULL
 	for( i in c((from+1):(current$num)) ){
-		if (is.null(tmp)) tmp <- getXKCD(i, display=F)
-		else tmp <- rbind(tmp, getXKCD(i, display=F))
+		if (is.null(tmp)) tmp <- getXKCD(i, display=FALSE)
+		else tmp <- rbind(tmp, getXKCD(i, display=FALSE))
 	}
 	suppressWarnings(tmp <- data.frame(tmp))
 	row.names(tmp) <- tmp$num
-	xkcd2add <- cbind( 
+	xkcd2add <- cbind(
 	"id"=unlist(tmp[["num"]]),
 	"img"=unlist(tmp[["img"]]),
 	"title"=unlist(tmp[["title"]]),
@@ -52,7 +54,7 @@ updateConfig <- function(){
 	"safe_title"=unlist(tmp[["safe_title"]]),
 	"transcript"=unlist(tmp[["transcript"]]),
 	"alt"=unlist(tmp[["alt"]]),
-	"day"=unlist(tmp[["day"]]) 
+	"day"=unlist(tmp[["day"]])
 	)
 	suppressWarnings(xkcd2add <- data.frame(xkcd2add))
 	row.names(xkcd2add) <- xkcd2add$num
@@ -64,9 +66,10 @@ updateConfig <- function(){
 #'
 #' Save XKCD database info into a file in the user directory
 #'
-#' This function saves the xkcd database as a file in the user's home directory
+#' This function saves the xkcd database as a file in the user's home
+#' directory.
 #'
-#' @references http://xkcd.com/license.html
+#' @references \url{http://xkcd.com/license.html}
 #'
 #' @export
 #'
@@ -80,26 +83,28 @@ saveConfig <- function(){
 	}
 }
 #'
-#' Search your favorite XKCD comic strip by title/trascript
+#' Search your favorite XKCD comic strip by title/transcript
 #'
-#' This function use grep to inspect the title and trascript for all the occurrences of a specified string and return a data.frame with both the number and the title of the XKCD comic strips.
+#' This function uses grep to inspect the title and transcript for all
+#' the occurrences of a specified string and returns a data.frame with
+#' both the number and the title of the XKCD comic strips.
 #'
 #' @param which string.
-#' @param xkcd.df A character string giving a xkcd file in csv format. By default the csv file in the data directory of the xkcd package are used.
 #'
-#' @return a data.frame containing the following fields: \itemize{
-#' \item num The num of the XKCD comic strip
-#' \item title The title of the XKCD comic strip
+#' @return a data.frame containing the following fields:
+#' \itemize{
+#'     \item num The num of the XKCD comic strip
+#'     \item title The title of the XKCD comic strip
 #' }
 #'
-#' @references http://xkcd.com/license.html
+#' @references \url{http://xkcd.com/license.html}
 #'
 #' @export
 #'
 #' @examples
 #' \dontrun{
 #' library("RXKCD")
-#' searchXKCD(which="significant") 
+#' searchXKCD(which="significant")
 #' searchXKCD(which="someone is wrong") }
 #'
 searchXKCD <- function(which="significant"){
@@ -114,37 +119,52 @@ searchXKCD <- function(which="significant"){
 	which.tt <- grep(which, xkcd.df["title"][[1]], ignore.case = TRUE, useBytes = TRUE)
 	which.tr <- grep(which, xkcd.df["transcript"][[1]], ignore.case =TRUE, useBytes = TRUE)
 	which.all <- unique(c(which.tr, which.tt))
-	} 
+	}
 	out <- data.frame(num=xkcd.df[which.all, "num"], title=xkcd.df[which.all, "title"])
-	return(out)	
+	return(out)
 }
 #'
-#' Display your favourite XKCD comic in R
+#' Display your favorite XKCD comic in R
 #'
-#' This function fetches a XKCD comic strip (randomly or by number) and displays it on screen.
+#' This function fetches a XKCD comic strip (randomly or by number)
+#' and displays it on screen.
 #'
-#' @param which string: either "current" or "random"; or a number indicating the specific strip.
-#' @param display  logical; TRUE (default) if you like to display the strip on the screen
-#' @param html logical; TRUE if you like to open the XKCD web page for the selected comic in your browser: 
-#' if TRUE it sets display and saveImg arguments to FALSE. Default FALSE
-#' @param saveImg logical; TRUE if you want to save image in the current directory. Default FALSE
+#' @param which string: either "current" or "random"; or a number
+#'     indicating the specific strip.
+#' @param display logical; TRUE (default) if you like to display the
+#'     strip on the screen.
+#' @param html logical; TRUE if you like to open the XKCD web page for
+#'     the selected comic in your browser: if TRUE it sets display and
+#'     saveImg arguments to FALSE. Default FALSE.
+#' @param saveImg logical; TRUE if you want to save image in the
+#'     current directory. Default FALSE.
 #'
 #' @return a list containing the following fields: \itemize{
-#' \item imgURL of the XKCD comic strip image (png)
-#' \item title Title of the XKCD comic strip
-#' \item month
-#' \item numNumber of the XKCD comic strip
-#' \item link
-#' \item year Year of publication
-#' \item safe_title
-#' \item transcript
-#' \item alt
-#' \item day
+#'     \item img URL of the XKCD comic strip image (png)
+#'     \item title Title of the XKCD comic strip
+#'     \item month
+#'     \item num Number of the XKCD comic strip
+#'     \item link
+#'     \item year Year of publication
+#'     \item safe_title
+#'     \item transcript
+#'     \item alt
+#'     \item day
+#'     \item news
 #' }
 #'
-#' @references http://xkcd.com/license.html
+#' @references \url{http://xkcd.com/license.html}
 #'
 #' @export
+#' @importFrom graphics par
+#' @importFrom graphics plot
+#' @importFrom graphics rasterImage
+#' @importFrom utils browseURL
+#' @importFrom utils download.file
+#' @importFrom jpeg readJPEG
+#' @importFrom png readPNG
+#' @importFrom png writePNG
+#' @importFrom RJSONIO fromJSON
 #'
 #' @examples
 #'
@@ -153,18 +173,18 @@ searchXKCD <- function(which="significant"){
 #'
 getXKCD <- function(which = "current", display = TRUE, html = FALSE, saveImg = FALSE) {
 	if (which=="current") xkcd <- fromJSON("http://xkcd.com/info.0.json")
-	else if(which=="random"|which=="") {
+	else if(which=="random" || which=="") {
 		current <- fromJSON("http://xkcd.com/info.0.json")
 		num <- sample(1:current["num"][[1]], 1)
 		xkcd <- fromJSON(paste("http://xkcd.com/",num,"/info.0.json",sep=""))
-	} 
-	else xkcd <- fromJSON(paste("http://xkcd.com/",which,"/info.0.json",sep=""))
-	class(xkcd) <- "rxkcd"	
-	if(html) {
-		display= FALSE
-		browseURL( paste("http://xkcd.com/", as.numeric(xkcd["num"][[1]]),sep="") ) 
 	}
-	if (display|saveImg) {
+	else xkcd <- fromJSON(paste("http://xkcd.com/",which,"/info.0.json",sep=""))
+	class(xkcd) <- "rxkcd"
+	if(html) {
+		display <- FALSE
+		browseURL( paste("http://xkcd.com/", as.numeric(xkcd["num"][[1]]),sep="") )
+	}
+	if (display || saveImg) {
 		if(grepl(".png",xkcd["img"][[1]])){
 			download.file(url=xkcd["img"][[1]], quiet=TRUE, mode="wb", destfile=paste(tempdir(),"xkcd.png",sep="/"))
 			xkcd.img <- readPNG( paste(tempdir(),"xkcd.png",sep="/") )
@@ -175,9 +195,24 @@ getXKCD <- function(which = "current", display = TRUE, html = FALSE, saveImg = F
 		} else stop("Unsupported image format! Try html = TRUE")
 		# show the image if the format is supported
 		if(display){
-			max.dim = max(dim(xkcd.img))
-			plot(1:max.dim, type="n", axes=F, xaxt="n",yaxt="n",xlab="",ylab="")
-			rasterImage(xkcd.img, xleft=0, ybottom=0, xright=dim(xkcd.img)[[2]], ytop=dim(xkcd.img)[[1]])
+			img_dim <- dim(xkcd.img)
+			plot(0:max(img_dim), type = "n", axes = FALSE,
+			     xaxt = "n", yaxt = "n", xlab = "", ylab = "")
+			usr <- par("usr")
+			pin <- par("pin")
+			pin_ratio <- pin[2] / pin[1]
+			img_ratio <- img_dim[1] / img_dim[2]
+			if (img_ratio > pin_ratio) {
+			    ytop <- usr[4]
+			    xright <- usr[1] + pin[2] / img_ratio / pin[1] *
+				(usr[2] - usr[1])
+			} else {
+			    ytop <- usr[3] + pin[1] * img_ratio / pin[2] *
+				(usr[4] - usr[3])
+			    xright <- usr[2]
+			}
+			rasterImage(xkcd.img, xleft = usr[1], ybottom = usr[3],
+				    xright = xright, ytop = ytop)
 		}
 		# save the image
 		if(saveImg) writePNG( image=xkcd.img, target=paste(xkcd$title,".png",sep="") )
